@@ -3,8 +3,8 @@ import pytest
 
 in_docker = pytest.mark.skipif(not os.environ.get('TOX_DOCKER') == '1', reason="Run only inside docker container")
 
-def need_os(os):
-    return pytest.mark.skipif(not os.environ.get('TOX_DISTRO') == os, reason="Run only on %s" % os)
+def need_os(os_needed):
+    return pytest.mark.skipif(not os.environ.get('TOX_DISTRO') == os_needed, reason="Run only on %s" % os)
 
 need_package = pytest.importorskip
 
